Fuller display than [print.lago()]: adds the confidence-set cost range and first rows, and the overall-test statistic and p-value when present.
Usage
# S3 method for class 'lago'
summary(object, ...)Fuller display than [print.lago()]: adds the confidence-set cost range and first rows, and the overall-test statistic and p-value when present.
# S3 method for class 'lago'
summary(object, ...)